scalably.clj-aws-lambda.snap-start


lambda-core-handlerclj


register-snap-start-lifecycle-handlersclj

(register-snap-start-lifecycle-handlers)
(register-snap-start-lifecycle-handlers handlers)

Register handlers for before-checkpoint and after-restore lifecycle events.

Existing handlers will be overwritten, so this can only be called ONCE

Register handlers for before-checkpoint and after-restore lifecycle events.

Existing handlers will be overwritten, so this can only be called ONCE
raw docstring

snap-start?clj

(snap-start?)

SnapStartLifecycleHandlercljprotocol

Support initialisation hooks for SnapStart Lambda functions

Support initialisation hooks for SnapStart Lambda functions

after-restoreclj

(after-restore _)

Called after restore. Use this to load/refresh resources

Called after restore. Use this to load/refresh resources

before-checkpointclj

(before-checkpoint _)

Warmup Java classes and/or free resources before checkpoint is taken

Warmup Java classes and/or free resources before checkpoint is taken
raw docstring

warm-lambda-core-classesclj

(warm-lambda-core-classes)

Touch core code to ensure classes are loaded and are hot (in the JVM hotspot sense)

Touch core code to ensure classes are loaded and are hot (in the JVM hotspot sense)
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries