(register-snap-start-lifecycle-handlers)(register-snap-start-lifecycle-handlers handlers)Register handlers for before-checkpoint and after-restore lifecycle events.
Existing handlers will be overwritten, so this can only be called ONCE
Register handlers for before-checkpoint and after-restore lifecycle events. Existing handlers will be overwritten, so this can only be called ONCE
(snap-start?)Support initialisation hooks for SnapStart Lambda functions
Support initialisation hooks for SnapStart Lambda functions
(after-restore _)Called after restore. Use this to load/refresh resources
Called after restore. Use this to load/refresh resources
(before-checkpoint _)Warmup Java classes and/or free resources before checkpoint is taken
Warmup Java classes and/or free resources before checkpoint is taken
(warm-lambda-core-classes)Touch core code to ensure classes are loaded and are hot (in the JVM hotspot sense)
Touch core code to ensure classes are loaded and are hot (in the JVM hotspot sense)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |